@@ -1,7 +1,11 @@
+from .commands import *
 from .errors import *
-from .utils import *
+from .members import *
+from .messages import *
+from .roles import *
+from .strings import *
 
-__version__ = "0.1.1"
+__version__ = "0.1.4"
 
 # MIT License
 #
